@@ -21,7 +21,8 @@ local = os.getenv('KUBERNETES_SERVICE_HOST',"") == ""
 class NumerousApp():
     def __init__(self, numerous_client: NumerousClient = None,
                  appname = "defaultnumerousApp",
-                 max_restarts = 0, numerous_job: NumerousBaseJob = None, model_folder: str = None):
+                 max_restarts = 0, numerous_job: NumerousBaseJob = None, model_folder: str = None,
+                 working_folder: str = None):
         log_level = os.getenv('LOG_LEVEL', logging.root.level)
 
         self.appname = appname
@@ -49,6 +50,7 @@ class NumerousApp():
         self.model_folder = model_folder
         self.numerous_job = numerous_job
         self.result = None
+        self.working_folder = working_folder
 
         self.setup_scenario()
 
@@ -176,12 +178,12 @@ def run_job(numerous_job=None, appname=None, max_restarts=0, model_folder="model
 
         logger.info(f"Welcome to numerous image tools. Base version {VERSION} - app {appname}")
 
-        #Change the working folder, so generated and downloaded files do not go in root of project
+        #  Create a temporary working folder, that can be used to place generated and downloaded files.
         os.makedirs(working_folder, exist_ok=True)
-        os.chdir(working_folder)
 
         app = NumerousApp(numerous_client=nc, appname=appname,
-                          max_restarts=max_restarts, numerous_job=numerous_job, model_folder=model_folder)
+                          max_restarts=max_restarts, numerous_job=numerous_job, model_folder=model_folder,
+                          working_folder=working_folder)
 
         app.terminate = terminate
         app.loop()
