@@ -134,8 +134,9 @@ class NumerousSystem:
         self.nc.set_scenario_progress('Environment Initializing',ScenarioStatus.ENVIRONMENT_INITIALIZING, 0.0, clean=True)
 
         # Initialize other system variables
-        self.component_list, self.components = self._format_job_spec(self.scenario)
-        self.unrolled_components = sort_components(self.component_list)
+        self.top_level_components = self._format_job_spec(self.scenario)
+        self.unrolled_components = sort_components(self.top_level_components)
+        self.components = {component.name: component for component in self.unrolled_components}
 
         # Download needed files
         self._download_custom_files()
@@ -255,7 +256,7 @@ class NumerousSystem:
 
         # Return list of components
 
-        return component_list, components
+        return component_list
 
     def _find_subcomponents(self, subcomps, simcomponents):
         subcomponents = []
@@ -307,7 +308,7 @@ class NumerousSystem:
                 path = f"{self._model_folder}.{model_file_name}"
         else:
             self.logger.warning(f'Skipping adding model for {component_name} as it does not obey requirements: '
-                                f'item_class is not None {item_class} and must be formatted as x.y/x.y.z '
+                                f'item_class is not None and must be formatted as x.y/x.y.z '
                                 f'(item_class: {item_class})')
 
         component_constants = {}
